==> thron-8.x-1.1.tar.gz: thron/src/Exception/THRONException.php <==
<?php

namespace Drupal\thron\Exception;

use Drupal\Core\Logger\LoggerChannelTrait;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Base exception class for THRON.
 */
abstract class ThronException extends \Exception {

  use LoggerChannelTrait;
  use MessengerTrait;
  use StringTranslationTrait;


  /**
   * Admin permission related to this exception.
   *
   * @var string
   */
  protected $adminPermission = 'administer thron configuration';

  /**
   * Message level to be used when displaying the message to the user.
   *
   * @var string
   */
  protected $messageLevel = 'error';

  /**
   * User-facing for admin users.
   *
   * @var string
   */
  protected $adminMessage;

  /**
   * Message to be logged in the Drupal's log.
   *
   * @var string
   */
  protected $logMessage;

  /**
   * Arguments for the log message.
   *
   * @var array
   */
  protected $logMessageArgs;

  /**
   * Constructs BundleNotExistException.
   *
   * @param $message
   * @param null $admin_message
   * @param null $log_message
   * @param array $log_message_args
   */
  public function __construct($message, $admin_message = NULL, $log_message = NULL, $log_message_args = []) {
    parent::__construct($message);
    $this->adminMessage = $admin_message ?: $message;
    $this->logMessage = $log_message ?: $this->adminMessage;
    $this->logMessageArgs = $log_message_args;
  }

  /**
   * Displays message to the user.
   */
  public function displayMessage() {
    if (\Drupal::currentUser()->hasPermission($this->adminPermission)) {
      $this->messenger()->addMessage($this->adminMessage, $this->messageLevel);
    }
    else {
      $this->messenger()->addMessage($this->getMessage(), $this->messageLevel);
    }
  }

  /**
   * Logs exception into Drupal's log.
   *
   * @return \Drupal\thron\Exception\ThronException
   *   This exception.
   */
  public function logException() {
    $this->getLogger('thron')->error($this->logMessage, $this->logMessageArgs);
    return $this;
  }

}

==> thron-8.x-1.3.tar.gz: thron/src/Exception/THRONException.php <==
<?php

namespace Drupal\thron\Exception;

use Drupal\Core\Logger\LoggerChannelTrait;
use Drupal\Core\Messenger\MessengerTrait;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Base exception class for THRON.
 */
abstract class ThronException extends \Exception {

  use LoggerChannelTrait;
  use MessengerTrait;
  use StringTranslationTrait;


  /**
   * Admin permission related to this exception.
   *
   * @var string
   */
  protected $adminPermission = 'administer thron configuration';

  /**
   * Message level to be used when displaying the message to the user.
   *
   * @var string
   */
  protected $messageLevel = 'error';

  /**
   * User-facing for admin users.
   *
   * @var string
   */
  protected $adminMessage;

  /**
   * Message to be logged in the Drupal's log.
   *
   * @var string
   */
  protected $logMessage;

  /**
   * Arguments for the log message.
   *
   * @var array
   */
  protected $logMessageArgs;

  /**
   * Constructs BundleNotExistException.
   *
   * @param string $message The message
   * @param NULL $admin_message The admin message, if present
   * @param NULL $log_message The log message, if present
   * @param array $log_message_args Arguments for the message
   */
  public function __construct($message, $admin_message = NULL, $log_message = NULL, $log_message_args = []) {
    parent::__construct($message);
    $this->adminMessage = $admin_message ?: $message;
    $this->logMessage = $log_message ?: $this->adminMessage;
    $this->logMessageArgs = $log_message_args;
  }

  /**
   * Displays message to the user.
   */
  public function displayMessage() {
    if (\Drupal::currentUser()->hasPermission($this->adminPermission)) {
      $this->messenger()->addMessage($this->adminMessage, $this->messageLevel);
    }
    else {
      $this->messenger()->addMessage($this->getMessage(), $this->messageLevel);
    }
  }

  /**
   * Logs exception into Drupal's log.
   *
   * @return \Drupal\thron\Exception\ThronException
   *   This exception.
   */
  public function logException() {
    $this->getLogger('thron')->error($this->logMessage, $this->logMessageArgs);
    return $this;
  }

}
